from .client.ftp import FTPResponse as FTPResponse
from .client.graphql import GraphQLResponse as GraphQLResponse
from .client.graphql_http2 import GraphQLHTTP2Response as GraphQLHTTP2Response
from .client.grpc import GRPCResponse as GRPCResponse
from .client.http import HTTPResponse as HTTPResponse
from .client.http2 import HTTP2Response as HTTP2Response
from .client.http3 import HTTP3Response as HTTP3Response
from .client.scp import SCPResponse as SCPResponse
from .client.sftp import SFTPResponse as SFTPResponse
from .client.smtp import EmailAttachment as EmailAttachment
from .client.smtp import SMTPResponse as SMTPResponse
from .client.playwright import PlaywrightResult as PlaywrightResult
from .client.tcp import TCPResponse as TCPResponse
from .client.udp import UDPResponse as UDPResponse
from .client.websocket import WebsocketResponse as WebsocketResponse
